%%% This script shows an example of how to use the functions
%%% `MakeKrigSurf.m' and `EvalKrigSurf.m' to construct and evaluate
%%% Krigifier surfaces, respectively, for use as test bed functions.

% Clean work space
clear all
close all
format compact
format shortG 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Construct and Evaluate Krigifier Surfaces %%%%%%%%%%%%%%%%%%%%%%%%%%
% User-specified section - only change items in the following section! %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% state the number of surfaces to be constructed
nsurf = 5;

% state the number of input dimensions for the surfaces
d = 3;

% state the mean (mu) and variance (sig2) to be used to construct the
% Krigifier surfaces
mu = 100;   
sig2 = 10;

% state a nsurf x d matrix of correlation pararmeter values to be used to 
% construct the Krigifier surfaces (each row is used for a new surface)
rho = .25 * ones(nsurf,d);

% state identification name to be used to save files
id='example';

% state the design points at which you would like to evaluate the surfaces
Xnew = lhsdesign(15,d);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% construct the Krigifier surfaces
MakeKrigSurf(nsurf, d, mu, sig2, rho, id)

% evaluate the Krigifier surfaces
K = EvalKrigSurf(id, Xnew)

str = sprintf(strcat('***The Krigifier surface evaluations are located in',...
' the Matlab variable K. ***'));
disp(str);